open Sdlvideo

let screen_width = 800
let screen_height = 600

let () =
  (* Initialisation de SDL *)
  Sdl.init [`TIMER; `VIDEO];
  Sdlevent.enable_events
    (Sdlevent.make_mask [
       Sdlevent.KEYDOWN_EVENT;
       Sdlevent.KEYUP_EVENT;
       Sdlevent.QUIT_EVENT;
     ]);
  Sdlttf.init ();
  at_exit Sdl.quit

let screen =
  set_video_mode
    ~w: screen_width
    ~h: screen_height
    ~bpp: 32
    [`HWSURFACE; `DOUBLEBUF]

let img_background = Sdlloader.load_image "background.png"
let img_player = Sdlloader.load_image "player.png"
let img_missile = Sdlloader.load_image "missile.png"
let img_blue_enemy = Sdlloader.load_image "enemyblue.png"
let img_red_enemy = Sdlloader.load_image "enemyred.png"
let img_explosion1 = Sdlloader.load_image "explosion1.png"
let img_explosion2 = Sdlloader.load_image "explosion2.png"
let img_explosion3 = Sdlloader.load_image "explosion3.png"
let img_explosion4 = Sdlloader.load_image "explosion4.png"

let font = Sdlttf.open_font "font.ttf" 20

let draw src x y =
  blit_surface
    ~src
    ~dst: screen
    ~dst_rect: {
      r_x = x;
      r_y = y;
      r_w = 0;
      r_h = 0;
    }
    ()

let draw_background x y =
  draw img_background x y

let draw_player x y =
  draw img_player (x - 20) (y - 30)

let draw_missile x y =
  draw img_missile (x - 2) (y - 2)

let draw_blue_enemy x y =
  draw img_blue_enemy (x - 15) (y - 15)

let draw_red_enemy x y =
  draw img_red_enemy (x - 15) (y - 15)

let draw_explosion n x y =
  match n with
    | 1 -> draw img_explosion1 (x - 15) (y - 15)
    | 2 -> draw img_explosion2 (x - 15) (y - 15)
    | 3 -> draw img_explosion3 (x - 15) (y - 15)
    | 4 -> draw img_explosion4 (x - 15) (y - 15)
    | _ -> invalid_arg "draw_explosion"

let draw_text x y txt =
  let txt = Sdlttf.render_text_blended font txt ~fg: white in
  blit_surface
    ~src: txt
    ~dst: screen
    ~dst_rect: {
      r_x = x;
      r_y = y;
      r_w = 0;
      r_h = 0;
    }
    ()

let draw_text_center x y txt =
  let (w, h) = Sdlttf.size_text font txt in
  draw_text (x - w / 2) (y - h / 2) txt

let update () =
  flip screen
