open Sdlkey
open Sdlevent

type t =
  | Left
  | Right
  | Up
  | Down
  | Fire1
  | Fire2
  | Quit

(* Liste des actions associées à chacune des touches du jeu. *)
let keys = [
  KEY_LEFT, Left;
  KEY_RIGHT, Right;
  KEY_UP, Up;
  KEY_DOWN, Down;
  KEY_RCTRL, Fire1;
  KEY_LCTRL, Fire1;
  KEY_RALT, Fire2;
  KEY_LALT, Fire2;
  KEY_ESCAPE, Quit;
]

(* Structure de données mémorisant un ensemble de touches. *)
module KeySet = Set.Make(struct
  type t = Sdlkey.t
  let compare = compare
end)

(* Mémorise les touches qui étaient pressées lors du dernier appel à [read]. *)
let pressed_keys = ref KeySet.empty

(* Lire les évènements pour mettre à jour [pressed_keys]. *)
let rec update_pressed_keys () =
  match poll () with
    | None ->
        ()
    | Some event ->
        begin match event with
          | KEYDOWN ke ->
              pressed_keys := KeySet.add ke.keysym !pressed_keys
          | KEYUP ke ->
              pressed_keys := KeySet.remove ke.keysym !pressed_keys
          | QUIT ->
              raise Exit
          | _ ->
              ()
        end;
        update_pressed_keys ()

(* Renvoyer la liste des actions dont la touche correspondante (d'après
   la liste [keys]) est pressée (d'après l'ensemble [pressed_keys]). *)
let extract_actions () =
  KeySet.fold
    (fun key acc ->
       try
         List.assoc key keys :: acc
       with Not_found ->
         acc)
    !pressed_keys
    []

let read () =
  update_pressed_keys ();
  extract_actions ()
